pub struct NativeGenerationHandle<T> { /* private fields */ }Expand description
Typed authority grant; cloning it does not grant admission or extend a lease.
Implementations
Sourceimpl<T> NativeGenerationHandle<T>
impl<T> NativeGenerationHandle<T>
Sourcepub fn acquire(&self) -> Result<NativeGenerationLease<T>, RuntimeFailure>
pub fn acquire(&self) -> Result<NativeGenerationLease<T>, RuntimeFailure>
Retain this lease for the complete operation, including spawned work.