pub struct NativePluginFactoryContext<'a> { /* private fields */ }Expand description
Immutable Plan input supplied when a native factory creates one generation.
Implementations
Sourceimpl<'a> NativePluginFactoryContext<'a>
impl<'a> NativePluginFactoryContext<'a>
Sourcepub const fn instance_key(self) -> &'a str
pub const fn instance_key(self) -> &'a str
Returns the App-local Plugin Instance key.
Sourcepub const fn entrypoint(self) -> &'a str
pub const fn entrypoint(self) -> &'a str
Returns the exact package entrypoint selected before boot.
Sourcepub const fn configuration(self) -> &'a str
pub const fn configuration(self) -> &'a str
Returns opaque Plugin-owned configuration selected before boot.
Sourcepub const fn resources(self) -> &'a InstanceResources
pub const fn resources(self) -> &'a InstanceResources
Returns immutable supporting files snapshotted for this Generation.
Sourcepub const fn facilities(self) -> &'a NativeFacilities
pub const fn facilities(self) -> &'a NativeFacilities
Returns only the Host attachments granted to this exact Instance.