pub struct NativePluginRegistry { /* private fields */ }Expand description
Statically linked native Plugin factories available to an App binary.
Implementations
Sourceimpl NativePluginRegistry
impl NativePluginRegistry
Sourcepub fn with_linked_factories(self) -> Self
pub fn with_linked_factories(self) -> Self
Adds every Plugin factory contributed to this Host at link time.
This catalog describes code available in the binary. The Resolved App Plan remains the sole authority that selects and binds Plugin Instances.
Sourcepub fn factories(&self) -> impl Iterator<Item = &dyn NativePluginFactory>
pub fn factories(&self) -> impl Iterator<Item = &dyn NativePluginFactory>
Returns the exact native factories available to this registry.
Sourcepub fn host_catalog(
slots: impl IntoIterator<Item = HostSlot>,
defaults: impl IntoIterator<Item = HostDefaultPlugin>,
) -> Result<HostCatalog, RuntimeFailure>
pub fn host_catalog( slots: impl IntoIterator<Item = HostSlot>, defaults: impl IntoIterator<Item = HostDefaultPlugin>, ) -> Result<HostCatalog, RuntimeFailure>
Builds the immutable Host Catalog declared by this binary and Host policy.
Sourcepub fn with_factory(self, factory: impl NativePluginFactory) -> Self
pub fn with_factory(self, factory: impl NativePluginFactory) -> Self
Adds one statically linked factory.