Crate lenso_native_adapter

Crate lenso_native_adapter 

Native Rust Execution Adapter for statically linked Module packages.

Structs

NativeModuleFactoryContext
Immutable Plan input supplied when a native factory creates one generation.
NativeModuleInstance
Endpoints created for one statically linked Module Instance generation.
NativeModuleRegistry
Statically linked native Module factories available to an App binary.

Traits

NativeModuleFactory
Adapter-specific factory for a statically linked native Rust Module.