Native Rust Execution Adapter for statically linked Module packages.
Structs
- Native
Module Factory Context - Immutable Plan input supplied when a native factory creates one generation.
- Native
Module Instance - Endpoints created for one statically linked Module Instance generation.
- Native
Module Registry - Statically linked native Module factories available to an App binary.
Traits
- Native
Module Factory - Adapter-specific factory for a statically linked native Rust Module.