pub struct NativeModuleRegistry { /* private fields */ }Expand description
Statically linked native Module factories available to an App binary.
Implementations
Sourceimpl NativeModuleRegistry
impl NativeModuleRegistry
Sourcepub fn with_linked_factories(self) -> Self
pub fn with_linked_factories(self) -> Self
Adds every Module factory contributed to this Host at link time.
This catalog describes code available in the binary. The Resolved App Plan remains the sole authority that selects and binds Module Instances.
Sourcepub fn factories(&self) -> impl Iterator<Item = &dyn NativeModuleFactory>
pub fn factories(&self) -> impl Iterator<Item = &dyn NativeModuleFactory>
Returns the exact native factories available to this registry.
Sourcepub fn with_factory(self, factory: impl NativeModuleFactory) -> Self
pub fn with_factory(self, factory: impl NativeModuleFactory) -> Self
Adds one statically linked factory.